@@ -8,8 +8,6 @@ from circe import (
     list_transformations,
     run,
 )
-import sys
-import os
 
 
 def run_cli():
