@@ -20,6 +20,7 @@ CONFIG = {
     "CIRCE_WEB_UI_CRYPT_KEY": "you should really change this",
     "CIRCE_WEB_UI_REMOVE_USER_FILES_DELAY": 7200,
     "CIRCE_TRANSFORMATIONS_MODULE": None,
+    "CIRCE_UPDATE_NOTIFY_ROUTE": False,
 }
 
 for key in CONFIG.keys():
@@ -31,6 +32,7 @@ for key in CONFIG.keys():
             "CIRCE_ACCESS_LOG",
             "CIRCE_IMMEDIATE_MODE",
             "CIRCE_ENABLE_WEB_UI",
+            "CIRCE_UPDATE_NOTIFY_ROUTE",
         ]:
             CONFIG[key] = True if val == "1" else False
         elif key in ["CIRCE_PORT"]:
