@@ -59,11 +59,6 @@ if CONFIG["CIRCE_TRANSFORMATIONS_MODULE"]:
                     transformations_module, transformation_name
                 )
 
-if not registered_transfos:
-    sys.exit(
-        "No transformations available. Have you set CIRCE_TRANSFORMATIONS_MODULE ?"
-    )
-
 
 def get_transformations_descriptions():
     descriptions = {}
